mailr19480 - in /branches/relax_disp: specific_analyses/relax_disp.py user_functions/relax_disp.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 15, 2013 - 18:28:
Author: bugman
Date: Mon Apr 15 18:28:20 2013
New Revision: 19480

URL: http://svn.gna.org/viewcvs/relax?rev=19480&view=rev
Log:
Expanded the relax_disp.exp_type user function to include the fixed period 
CPMG experiments.


Modified:
    branches/relax_disp/specific_analyses/relax_disp.py
    branches/relax_disp/user_functions/relax_disp.py

Modified: branches/relax_disp/specific_analyses/relax_disp.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/specific_analyses/relax_disp.py?rev=19480&r1=19479&r2=19480&view=diff
==============================================================================
--- branches/relax_disp/user_functions/relax_disp.py (original)
+++ branches/relax_disp/user_functions/relax_disp.py Mon Apr 15 18:28:20 2013
@@ -214,8 +214,8 @@
 
 # The relax_disp.exp_type user function.
 uf = uf_info.add_uf('relax_disp.exp_type')
-uf.title = "Select the type of relaxation dispersion experiments to analyse."
-uf.title_short = "Relaxation dispersion type selection."
+uf.title = "Select the type of relaxation dispersion experiments to be 
analysed."
+uf.title_short = "Relaxation dispersion experiment type selection."
 uf.add_keyarg(
     name = "exp_type",
     default = "cpmg",
@@ -225,17 +225,30 @@
     wiz_element_type = "combo",
     wiz_combo_choices = [
         "CPMG",
+        "CPMG, fixed time",
         "R1rho"
     ],
     wiz_combo_data = [
         "cpmg",
+        "cpmg fixed",
         "r1rho"
     ],
     wiz_read_only = True
 )
 # Description.
 uf.desc.append(Desc_container())
-uf.desc[-1].add_paragraph("The supported experiments will include CPMG 
('cpmg') and R1rho ('r1rho').")
+uf.desc[-1].add_paragraph("The currently supported experiments include:")
+uf.desc[-1].add_item_list_element("'cpmg'", "The CPMG family of experiments 
whereby spectra consist of exponential curves by varying the total time of 
the CPMG block of pulses,")
+uf.desc[-1].add_item_list_element("'cpmg fixed'", "The CPMG family of 
experiments whereby the time period for the block of CPMG pulses is fixed and 
a reference spectrum is present,")
+uf.desc[-1].add_item_list_element("'r1rho'", "The R1rho family of 
experiments whereby spectra consist of exponential curves by varying the 
total time in which the spin-lock field is applied.")
+uf.desc[-1].add_paragraph("For the 'cpmg' and 'r1rho' experiment types, 
2-parameter exponentials will be fit to obtain R2,eff for each spin system as 
part of the optimisation of the dispersion model.")
+uf.desc[-1].add_paragraph("For the 'cpmg fixed' experiment type, the R2,eff 
values are directly calculated prior to optimisation using the formula:")
+uf.desc[-1].add_verbatim("""
+                        -1         / I1(nu_CPMG) \ 
+    R2,eff(nu_CPMG) = ------- * ln | ----------- |,
+                      relax_T      \     I0      /
+""")
+uf.desc[-1].add_paragraph("where nu_CPMG is the CPMG frequency in Hz, 
relax_T is the fixed delay time, I0 is the reference peak intensity when 
relax_T is zero, and I1 is the peak intensity in a spectrum for a given 
nu_CPMG frequency.")
 # Prompt examples.
 uf.desc.append(Desc_container("Prompt examples"))
 uf.desc[-1].add_paragraph("To pick the experiment type 'cpmg' for all 
selected spins, type one of:")
@@ -243,7 +256,9 @@
 uf.desc[-1].add_prompt("relax> relax_disp.exp_type(exp_type='cpmg')")
 uf.backend = relax_disp_obj._exp_type
 uf.menu_text = "&exp_type"
-uf.wizard_size = (800, 400)
+uf.wizard_height_desc = 500
+uf.wizard_size = (1000, 700)
+uf.wizard_apply_button = False
 
 
 # The relax_disp.relax_time user function.




Related Messages


Powered by MHonArc, Updated Mon Apr 15 18:40:02 2013
--- branches/relax_disp/specific_analyses/relax_disp.py (original)
+++ branches/relax_disp/specific_analyses/relax_disp.py Mon Apr 15 18:28:20 
2013
@@ -613,14 +613,19 @@
         if not exists_mol_res_spin_data():
             raise RelaxNoSequenceError
 
         # CPMG relaxation dispersion experiments.
varying relax_T).
         if exp_type == 'cpmg':
-            print("CPMG relaxation dispersion experiments.")
+            print("CPMG experiments with exponential curves from varying the 
relaxation period.")
             cdp.exp_type = 'cpmg'
+
+        # CPMG relaxation dispersion experiments (fixed relax_T).
+        elif exp_type == 'cpmg fixed':
+            print("CPMG experiments with a fixed relaxation period.")
+            cdp.exp_type = 'cpmg fixed'
 
         # R1rho relaxation dispersion experiments.
         elif exp_type == 'r1rho':
-            print("R1rho relaxation dispersion experiments.")
+            print("R1rho experiments with exponential curves from varying 
the time of application of the spin-lock field.")
             cdp.exp_type = 'r1rho'
 
@@ -613,14 +613,19 @@
             raise RelaxNoSequenceError
 
-        # CPMG relaxation dispersion experiments.
+        # CPMG relaxation dispersion experiments (exponential curves with 
varying relax_T).
         if exp_type == 'cpmg':
         # Invalid relaxation dispersion experiment.

Modified: branches/relax_disp/user_functions/relax_disp.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/relax_disp/user_functions/relax_disp.py?rev=19480&r1=19479&r2=19480&view=diff
==============================================================================